Learn R Programming

plspm.formula (version 1.0.1)

plspm.formula-package: Formula Based PLS Path Modeling

Description

The main objective is to make easy the PLS Path Modeling with R using the package 'plspm'. It compute automatically the inner matrix and the outer list the 'plspm' function need simply by specify the model using formulas.

Arguments

Details

A formula based version of the package 'plspm'.The main fonction is 'plspm.formula' based on the plspm function.

References

Gaston Sanchez, Laura Trinchera and Giorgio Russolillo (2015). plspm: Tools for Partial Least Squares Path Modeling (PLS-PM). R package version 0.4.7. http://CRAN.R-project.org/package=plspm

See Also

plspm.formula